pub struct SetChatPhoto { /* private fields */ }Expand description
Sets a new profile photo for a chat.
Photos can’t be changed for private chats The bot must be an administrator in the chat for this to work and must have the appropriate admin rights.
Notes
In regular groups (non-supergroups), this method will only work if the ‘All Members Are Admins’ setting is off in the target group.
Implementations
Sourceimpl SetChatPhoto
impl SetChatPhoto